@@ -1,12 +1,9 @@
-"""
-    octocat description.
-
-"""
+""" octocat description. """
 
 # Package information
 # ===================
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __project__ = "octocat"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
-__license__ = "BSD"
\ No newline at end of file
+__license__ = "BSD"
